@@ -89,12 +89,29 @@ public class PhotoView : EventBox {
 	private struct SelectionConstraint {
 		public string Label;
 		public double XyRatio;
+		
+		public SelectionConstraint (string label, double ratio)
+		{
+			Label = label;
+			XyRatio = ratio;
+		}
 	}
 
 	private OptionMenu constraints_option_menu;
 	private int selection_constraint_ratio_idx;
 
-	private static SelectionConstraint [] constraints;
+	private static SelectionConstraint [] constraints = {
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("No Constraint"), 0.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("4 x 3 (Book)"), 4.0 / 3.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("4 x 6 (Postcard)"), 6.0 / 4.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("5 x 7 (L, 2L)"), 7.0 / 5.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("8 x 10"), 10.0 / 8.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("4 x 3 Portrait (Book)"), 3.0 / 4.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("4 x 6 Portrait (Postcard)"), 4.0 / 6.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("5 x 7 Portrait (L, 2L)"), 5.0 / 7.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("8 x 10 Portrait"), 8.0 / 10.0),
+		new SelectionConstraint (Mono.Posix.Catalog.GetString ("Square"), 1.0)
+	};
 
 	private void HandleSelectionConstraintOptionMenuActivated (object sender, EventArgs args)
 	{
@@ -263,10 +280,12 @@ public class PhotoView : EventBox {
 		// be fixed there.
 		photo_view.Pixbuf = edited;
 		photo_view.UnsetSelection ();
+		bool version = false;
 
 		try {
 			if (photo.DefaultVersionId == Photo.OriginalVersionId) {
 				photo.DefaultVersionId = photo.CreateDefaultModifiedVersion (photo.DefaultVersionId, false);
+				version = true;
 				PixbufUtils.SaveJpeg (edited, photo.DefaultVersionPath, 
 						      95, exif_data);
 				FSpot.ThumbnailGenerator.Create (photo.DefaultVersionPath).Dispose ();
@@ -278,9 +297,20 @@ public class PhotoView : EventBox {
 				FSpot.ThumbnailGenerator.Create (photo.DefaultVersionPath).Dispose ();
 				query.MarkChanged (CurrentPhoto);
 			}
-		} catch (GLib.GException ex) {
-			// FIXME error dialog.
-			Console.WriteLine ("error {0}", ex);
+		} catch (System.Exception e) {
+			string msg = Mono.Posix.Catalog.GetString ("Error editing photo");
+			string desc = String.Format (Mono.Posix.Catalog.GetString ("Received exception \"{0}\". Unable to save image {1}"),
+						     e.Message, photo.Name);
+
+			HigMessageDialog md = new HigMessageDialog ((Gtk.Window)this.Toplevel, DialogFlags.DestroyWithParent, 
+								    Gtk.MessageType.Error, ButtonsType.Ok, 
+								    msg,
+								    desc);
+			md.Run ();
+			md.Destroy ();
+
+			if (version)
+				photo.DeleteVersion (photo.DefaultVersionId);
 		}
 		
 		photo_view.Fit = true;
@@ -298,7 +328,19 @@ public class PhotoView : EventBox {
 	{
 		if (description_delay.IsPending) {
 			description_delay.Stop ();
+
+#if UPDATE_EXIF_DESCRIPTION
+			Photo photo = query.Photos [description_photo];
+			FSpot.ImageFile img = FSpot.ImageFile.Create (photo.DefaultVersionPath);
+			if (img is FSpot.JpegFile) {
+				FSpot.JpegFile jimg = img as FSpot.JpegFile;
+				jimg.Description = photo.Description;
+				jimg.SaveMetaData (photo.DefaultVersionPath);
+			}
+			Query.Store.Commit (photo);
+#else
 			Query.Commit (description_photo);
+#endif
 		}
 		return true;
 	}
@@ -332,41 +374,6 @@ public class PhotoView : EventBox {
 		}
 	}
 
-	static PhotoView ()
-	{
-		constraints = new SelectionConstraint [10];
-
-		constraints[0].Label = "No Constraint";
-		constraints[0].XyRatio = 0.0;
-
-		constraints[1].Label = "4 x 3 (Book)";
-		constraints[1].XyRatio = 4.0 / 3.0;
-
-		constraints[2].Label = "4 x 6 (Postcard)";
-		constraints[2].XyRatio = 6.0 / 4.0;
-
-		constraints[3].Label = "5 x 7 (L, 2L)";
-		constraints[3].XyRatio = 7.0 / 5.0;
-
-		constraints[4].Label = "8 x 10";
-		constraints[4].XyRatio = 10.0 / 8.0;
-
-		constraints[5].Label = "4 x 3 Portrait (Book)";
-		constraints[5].XyRatio = 3.0 / 4.0;
-
-		constraints[6].Label = "4 x 6 Portrait (Postcard)";
-		constraints[6].XyRatio = 4.0 / 6.0;
-
-		constraints[7].Label = "5 x 7 Portrait (L, 2L)";
-		constraints[7].XyRatio = 5.0 / 7.0;
-
-		constraints[8].Label = "8 x 10 Portrait";
-		constraints[8].XyRatio = 8.0 / 10.0;
-
-		constraints[9].Label = "Square";
-		constraints[9].XyRatio = 1.0;
-	}
-
 	private void HandlePhotoChanged (FSpot.PhotoImageView view)
 	{
 		CommitPendingChanges ();
@@ -391,7 +398,7 @@ public class PhotoView : EventBox {
 		this.query = query;
 		this.photo_store = photo_store;
 
-		description_delay = new FSpot.Delay (500, new GLib.IdleHandler (CommitPendingChanges));
+		description_delay = new FSpot.Delay (1000, new GLib.IdleHandler (CommitPendingChanges));
 		this.Destroyed += HandleDestroy;
 
 
